function [dmap, minDiffs] = compStereo (left, right, drange, nsize, border, nodisp)
% [dmap minDiffs] = compStereo (left, right, drange, nsize, border)
% implements a simple region based stereo correspondence algorithm based on
% minimizing the sum of absolute differences between square patches of the
% input left and right images. It is assumed that the input matrices are of
% type double (e.g. convolution results). The function considers disparities
% over the range from -drange to +drange. The size of the patches is 
% 2*nsize+1 pixels on each side. A border around the image of the input 
% border size is not included in the analysis of disparity. The function 
% returns the computed disparity map and matrix of the minimum differences 
% corresponding to the best disparity at each location. The input nodisp is 
% stored in locations where no disparity is computed.

[rows, cols] = size(left);        % get size of input image
dmap = nodisp*ones(rows,cols);    % matrix to store the best disparities
minDiffs = zeros(rows,cols);      % matrix to store minimum sum of absolute 
                                        % differences
% first/last row/column for the image region where disparity is computed
r1 = 1 + nsize + border;
rlast = rows - nsize - border;
c1 = 1 + nsize + border + drange;
clast = cols - nsize - border - drange;

% insert new code

end

