% stereoScript.m

% specialized script to process stereo images of a collection of objects at 
% different depths

disp('loading images...');
left = imread('left.jpg');
right = imread('right.jpg');
% open a figure window with a particular size and position, and display 
% the two stereo images in the same window using subplot
figure('Position', [100 100 800 400])
subplot(1,2,1)  
imshow(left)
subplot(1,2,2)
imshow(right)

disp('computing convolutions...');
% convolve the images with a laplacian-of-gaussian operator, w = 4
lapOp = laplacian(4.0);
cleft = conv2D(left,lapOp);
cright = conv2D(right,lapOp);
% width of border where no convolution values are computed
border = fix(size(lapOp,1)/2);
zcLeft = zeros2D(cleft);    % zero-crossings of left convolution
% display convolution results
figure('Position', [100 100 800 400])
subplot(1,2,1)
imshow(cleft, [])
subplot(1,2,2)
imshow(cright, [])

disp('computing stereo disparities...');
% set up additional parameters for stereo correspondence process
drange = 20;
nsize = 20;
% nodisp is used to indicate that no disparity is computed at a location
nodisp = -drange - 5;   
[dmap, minDiffs] = compStereo(cleft, cright, drange, nsize, border, nodisp);
% display depth map, minimum differences, and depth map with 
% zero-crossings overlaid
displayImage(dmap,0);
displayImage(minDiffs,0);
displayOverlay(dmap, zcLeft);

